dbus-glib: result of autoreconf after the --with-dbus-binding-tool addition

autoreconf on dbus-glib fails with the autoconf version we currently have
in BR, so do it in patch form instead.

Signed-off-by: Peter Korsgaard <jacmet@sunsite.dk>
---
 configure                              |   14 ++++++++++++++
 dbus/Makefile.in                       |    1 +
 dbus/examples/Makefile.in              |    5 +++--
 dbus/examples/statemachine/Makefile.in |    5 +++--
 test/core/Makefile.in                  |    7 ++++---
 test/interfaces/Makefile.in            |   13 +++++++------
 tools/Makefile.in                      |    3 ++-
 7 files changed, 34 insertions(+), 14 deletions(-)

Index: dbus-glib-0.80/configure
===================================================================
--- dbus-glib-0.80.orig/configure
+++ dbus-glib-0.80/configure
@@ -882,6 +882,7 @@
 SED
 DBUS_BUILD_TESTS_FALSE
 DBUS_BUILD_TESTS_TRUE
+DBUS_BINDING_TOOL
 DBUS_BASH_COMPLETION_FALSE
 DBUS_BASH_COMPLETION_TRUE
 EGREP
@@ -1003,6 +1004,7 @@
 enable_bash_completion
 with_test_socket_dir
 with_introspect_xml
+with_dbus_binding_tool
 enable_shared
 enable_static
 enable_fast_install
@@ -1696,6 +1698,8 @@
                           Pass in a pregenerated dbus daemon introspection xml
                           file (as generated by 'dbus-daemon --introspect') to
                           use instead of querying the installed dbus daemon
+  --with-dbus-binding-tool=filename
+                          Use external dbus-binding-tool program
   --with-gnu-ld           assume the C compiler uses GNU ld [default=no]
   --with-pic              try to use only PIC/non-PIC objects [default=use
                           both]
@@ -5174,6 +5178,16 @@
 fi
 
 
+# Check whether --with-dbus-binding-tool was given.
+if test "${with_dbus_binding_tool+set}" = set; then
+  withval=$with_dbus_binding_tool; DBUS_BINDING_TOOL=$withval
+else
+  DBUS_BINDING_TOOL=\$\(top_builddir\)/dbus/dbus-binding-tool
+fi
+
+
+
+
  if test x$enable_tests = xyes; then
   DBUS_BUILD_TESTS_TRUE=
   DBUS_BUILD_TESTS_FALSE='#'
Index: dbus-glib-0.80/dbus/examples/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/dbus/examples/Makefile.in
+++ dbus-glib-0.80/dbus/examples/Makefile.in
@@ -114,6 +114,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
@@ -668,10 +669,10 @@
 
 
 example-service-glue.h: example-service.xml
-	$(LIBTOOL) --mode=execute $(top_builddir)/dbus/dbus-binding-tool --prefix=some_object --mode=glib-server --output=example-service-glue.h $(srcdir)/example-service.xml
+	$(LIBTOOL) --mode=execute $(DBUS_BINDING_TOOL) --prefix=some_object --mode=glib-server --output=example-service-glue.h $(srcdir)/example-service.xml
 
 example-signal-emitter-glue.h: example-signal-emitter.xml
-	$(LIBTOOL) --mode=execute $(top_builddir)/dbus/dbus-binding-tool --prefix=test_object --mode=glib-server --output=example-signal-emitter-glue.h $(srcdir)/example-signal-emitter.xml
+	$(LIBTOOL) --mode=execute $(DBUS_BINDING_TOOL) --prefix=test_object --mode=glib-server --output=example-signal-emitter-glue.h $(srcdir)/example-signal-emitter.xml
 # Tell versions [3.59,3.63) of GNU make to not export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
 .NOEXPORT:
Index: dbus-glib-0.80/dbus/examples/statemachine/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/dbus/examples/statemachine/Makefile.in
+++ dbus-glib-0.80/dbus/examples/statemachine/Makefile.in
@@ -87,6 +87,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
@@ -529,10 +530,10 @@
 
 
 statemachine-server-glue.h: statemachine-server.xml
-	$(LIBTOOL) --mode=execute $(top_builddir)/dbus/dbus-binding-tool --prefix=sm_server --mode=glib-server --output=$@ $<
+	$(LIBTOOL) --mode=execute $(DBUS_BINDING_TOOL) --prefix=sm_server --mode=glib-server --output=$@ $<
 
 statemachine-glue.h: statemachine.xml
-	$(LIBTOOL) --mode=execute $(top_builddir)/dbus/dbus-binding-tool --prefix=sm_object --mode=glib-server --output=$@ $<
+	$(LIBTOOL) --mode=execute $(DBUS_BINDING_TOOL) --prefix=sm_object --mode=glib-server --output=$@ $<
 
 sm-marshal.c: Makefile sm-marshal.list
 	@GLIB_GENMARSHAL@ --prefix=sm_marshal $(srcdir)/sm-marshal.list --header --body > $@.tmp && mv $@.tmp $@
Index: dbus-glib-0.80/test/core/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/test/core/Makefile.in
+++ dbus-glib-0.80/test/core/Makefile.in
@@ -175,6 +175,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
@@ -767,13 +768,13 @@
 
 
 @DBUS_BUILD_TESTS_TRUE@test-service-glib-glue.h: test-service-glib.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(top_builddir)/dbus/dbus-binding-tool --prefix=my_object --mode=glib-server --output=test-service-glib-glue.h $(srcdir)/test-service-glib.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(DBUS_BINDING_TOOL) --prefix=my_object --mode=glib-server --output=test-service-glib-glue.h $(srcdir)/test-service-glib.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-service-glib-subclass-glue.h: test-service-glib-subclass.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(top_builddir)/dbus/dbus-binding-tool --prefix=my_object_subclass --mode=glib-server --output=test-service-glib-subclass-glue.h $(srcdir)/test-service-glib-subclass.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(DBUS_BINDING_TOOL) --prefix=my_object_subclass --mode=glib-server --output=test-service-glib-subclass-glue.h $(srcdir)/test-service-glib-subclass.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-service-glib-bindings.h: test-service-glib.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(top_builddir)/dbus/dbus-binding-tool --prefix=my_object --mode=glib-client --output=test-service-glib-bindings.h $(srcdir)/test-service-glib.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DEBUG) $(DBUS_BINDING_TOOL) --prefix=my_object --mode=glib-client --output=test-service-glib-bindings.h $(srcdir)/test-service-glib.xml
 
 @DBUS_BUILD_TESTS_TRUE@my-object-marshal.c: Makefile my-object-marshal.list
 @DBUS_BUILD_TESTS_TRUE@	@GLIB_GENMARSHAL@ --prefix=my_object_marshal $(srcdir)/my-object-marshal.list --header --body > my-object-marshal.c
Index: dbus-glib-0.80/test/interfaces/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/test/interfaces/Makefile.in
+++ dbus-glib-0.80/test/interfaces/Makefile.in
@@ -104,6 +104,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
@@ -637,22 +638,22 @@
 
 
 @DBUS_BUILD_TESTS_TRUE@test-song-glue.h: test-song.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_song --mode=glib-server --output=test-song-glue.h $(srcdir)/test-song.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_song --mode=glib-server --output=test-song-glue.h $(srcdir)/test-song.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-song-bindings.h: test-song.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_song --mode=glib-client --output=test-song-bindings.h $(srcdir)/test-song.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_song --mode=glib-client --output=test-song-bindings.h $(srcdir)/test-song.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-hello-glue.h: test-hello.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_hello --mode=glib-server --output=test-hello-glue.h $(srcdir)/test-hello.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_hello --mode=glib-server --output=test-hello-glue.h $(srcdir)/test-hello.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-hello-bindings.h: test-hello.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_hello --mode=glib-client --output=test-hello-bindings.h $(srcdir)/test-hello.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_hello --mode=glib-client --output=test-hello-bindings.h $(srcdir)/test-hello.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-goodbye-glue.h: test-goodbye.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_goodbye --mode=glib-server --output=test-goodbye-glue.h $(srcdir)/test-goodbye.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_goodbye --mode=glib-server --output=test-goodbye-glue.h $(srcdir)/test-goodbye.xml
 
 @DBUS_BUILD_TESTS_TRUE@test-goodbye-bindings.h: test-goodbye.xml $(top_builddir)/dbus/dbus-binding-tool
-@DBUS_BUILD_TESTS_TRUE@	$(top_builddir)/dbus/dbus-binding-tool --prefix=test_goodbye --mode=glib-client --output=test-goodbye-bindings.h $(srcdir)/test-goodbye.xml
+@DBUS_BUILD_TESTS_TRUE@	$(DBUS_BINDING_TOOL) --prefix=test_goodbye --mode=glib-client --output=test-goodbye-bindings.h $(srcdir)/test-goodbye.xml
 
 ### not building tests
 # Tell versions [3.59,3.63) of GNU make to not export all variables.
Index: dbus-glib-0.80/tools/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/tools/Makefile.in
+++ dbus-glib-0.80/tools/Makefile.in
@@ -77,6 +77,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
@@ -481,7 +482,7 @@
 
 
 dbus-glib-bindings.h: dbus-bus-introspect.xml $(top_builddir)/dbus/dbus-binding-tool$(EXEEXT)
-	$(top_builddir)/dbus/dbus-binding-tool --mode=glib-client --prefix=dbus_bus --output=dbus-glib-bindings.h dbus-bus-introspect.xml
+	$(DBUS_BINDING_TOOL) --mode=glib-client --prefix=dbus_bus --output=dbus-glib-bindings.h dbus-bus-introspect.xml
 
 @USE_INTROSPECT_XML_TRUE@dbus-bus-introspect.xml: $(INTROSPECT_XML_PATH)
 @USE_INTROSPECT_XML_TRUE@	cp $(INTROSPECT_XML_PATH) dbus-bus-introspect.xml
Index: dbus-glib-0.80/dbus/Makefile.in
===================================================================
--- dbus-glib-0.80.orig/dbus/Makefile.in
+++ dbus-glib-0.80/dbus/Makefile.in
@@ -158,6 +158,7 @@
 CXXFLAGS = @CXXFLAGS@
 CYGPATH_W = @CYGPATH_W@
 DATADIRNAME = @DATADIRNAME@
+DBUS_BINDING_TOOL = @DBUS_BINDING_TOOL@
 DBUS_BUS_CFLAGS = @DBUS_BUS_CFLAGS@
 DBUS_BUS_LIBS = @DBUS_BUS_LIBS@
 DBUS_CFLAGS = @DBUS_CFLAGS@
